@@ -361,7 +361,7 @@ class BatchProcessor:
         )
         # fmt: on
 
-    def update_hang_status(self):
+    def _update_hang_status(self):
         self.db.update_batch_hang_status()
 
     def retry_hung_jobs(self):
@@ -403,10 +403,10 @@ class BatchProcessor:
         # fmt: off
         status = {
             "status": self.db.get_status_counts(),
-#            "last": self.db.get_last_jobs(limit=20),
-#            "last_failed": self.db.get_last_jobs(limit=20, status=["failed"]),
-#            "last_pending": self.db.get_last_jobs(limit=20, status=["pending"]),
-#            "last_in_progress": self.db.get_last_jobs(limit=20, status=["in-progress"]),
+#            "last": self.db.get_jobs(limit=20),
+#            "last_failed": self.db.get_jobs(limit=20, status=["failed"]),
+#            "last_pending": self.db.get_jobs(limit=20, status=["pending"]),
+#            "last_in_progress": self.db.get_jobs(limit=20, status=["in-progress"]),
             "counts": self.get_job_counts()}
         # fmt: on
         return status
@@ -416,7 +416,7 @@ class BatchProcessor:
         now = datetime.datetime.now()
         if now - self.last_cleanup_time > datetime.timedelta(seconds=CLEANUP_INTERVAL_MS):
             self.last_cleanup_time = now
-            self.update_hang_status()
+            self._update_hang_status()
         # Try to process one item
         if not self.execute_one_throttled_batch_item():
             # Put a status
