@@ -214,7 +214,7 @@ $$ language plpgsql;
                             when
                                 b.status is distinct from %(in_progress_status)s
                             and
-                                %(status)s = %(in_progress_status)s
+                                %(to_status)s = %(in_progress_status)s
                             then
                                 now()
                             else
@@ -226,7 +226,7 @@ $$ language plpgsql;
                             when
                                 b.status = %(in_progress_status)s
                             and
-                                %(status)s is distinct from %(in_progress_status)s
+                                %(from_status)s is distinct from %(in_progress_status)s
                             then
                                 now()
                             else
@@ -346,7 +346,7 @@ $$ language plpgsql;
                           when
                               b.status is distinct from %(in_progress_status)s
                           and
-                              %(status)s = %(in_progress_status)s
+                              %(to_status)s = %(in_progress_status)s
                           then
                               now()
                           else
@@ -357,7 +357,7 @@ $$ language plpgsql;
                           when
                               b.status = %(in_progress_status)s
                           and
-                              %(status)s is distinct from %(in_progress_status)s
+                              %(from_status)s is distinct from %(in_progress_status)s
                           then
                               now()
                           else
@@ -411,7 +411,7 @@ $$ language plpgsql;
                           when
                               b.status is distinct from %(in_progress_status)s
                           and
-                              %(status)s = %(in_progress_status)s
+                              %(to_status)s = %(in_progress_status)s
                           then
                               now()
                           else
@@ -422,7 +422,7 @@ $$ language plpgsql;
                           when
                               b.status = %(in_progress_status)s
                           and
-                              %(status)s is distinct from %(in_progress_status)s
+                              %(from_status)s is distinct from %(in_progress_status)s
                           then
                               now()
                           else
@@ -601,7 +601,7 @@ $$ language plpgsql;
                     %(limit)s
                 ;
                 """,
-            {"id": (id,), "priority": (priority,), "type": (type,), "status": (status,), "throttle_key": (throttle_key,), "source": (source,), "error": (error,), "limit": (limit,)},
+            {"id": (id,), "priority": (priority,), "ttl_seconds": (ttl_seconds,), "type": (type,), "status": (status,), "throttle_key": (throttle_key,), "error": (error,), "source": (source,), "limit": (limit,)},
         )
 
     #    , min( extract('epoch' from updated_at - created_at)) as low
